commit e61cd137aeee9dc354fa29a9d13398200a1baeca
Author: Moritz Bunkus <m.bunkus@linet.de>
Date:   Fri Feb 10 13:20:36 2017 +0100

    Testfehler: typische Schreibfehler gefixt

diff --git a/SL/Controller/DownloadZip.pm b/SL/Controller/DownloadZip.pm
index f1a6fa6a6..57c436a2f 100644
--- a/SL/Controller/DownloadZip.pm
+++ b/SL/Controller/DownloadZip.pm
@@ -20,7 +20,7 @@ sub action_download_orderitems_files {
   # in kivitendo.conf some regex may be defined:
   # For no values just let it commented out
   # PA = Produktionsauftrag, L = Lieferschein, ML = Materialliste
-  # If you want several options, please seperate the letter with '|'. Example: '^(PA|L).*'
+  # If you want several options, please separate the letter with '|'. Example: '^(PA|L).*'
   #set_sales_documenttype_for_delivered_quantity = '^(LS).*'
   #set_purchase_documenttype_for_delivered_quantity = '^(EL).*'
   #
diff --git a/SL/Controller/File.pm b/SL/Controller/File.pm
index 05884dd4f..875478fb2 100644
--- a/SL/Controller/File.pm
+++ b/SL/Controller/File.pm
@@ -604,7 +604,7 @@ SL::Controller::File - Controller for managing files
 
 =head1 DESCRIPTION
 
-This is a controller for handling files in a storage independant way.
+This is a controller for handling files in a storage independent way.
 The storage may be a Filesystem,a WebDAV, a Database or DMS.
 These backends must be configered in ClientConfig.
 This Controller use as intermediate layer for storage C<SL::File>.
@@ -619,7 +619,7 @@ More description of the intermediate layer see L<SL::File>.
 =head2 C<action_list>
 
 This loads a list of files on a webpage. This can be done with a normal submit or via an ajax/json call.
-Dependant of file_type different sources are available.
+Dependent of file_type different sources are available.
 
 For documents there are the 'created' source and the imports from scanners or email.
 For attachments and images only the 'uploaded' source available.
@@ -744,7 +744,7 @@ The ids of the files to delete. Only this files are deleted not all versions of
 
 =head2 C<action_ajax_unimport>
 
-Some files can be unimported, dependant of the source of the file. This means they are moved
+Some files can be unimported, dependent of the source of the file. This means they are moved
 back to the directory of the source
 
 Available C<FORM PARAMS>:
@@ -767,4 +767,3 @@ One file can be renamed. There can be some checks if the same filename still exi
 Martin Helmling E<lt>martin.helmling@opendynamic.deE<gt>
 
 =cut
-
diff --git a/SL/File/Backend.pm b/SL/File/Backend.pm
index a2ffe7312..2f1da83d3 100644
--- a/SL/File/Backend.pm
+++ b/SL/File/Backend.pm
@@ -104,7 +104,7 @@ all version of the file are deleted.
 
 =item C<rename PARAMS>
 
-The Filename of the file is changed. If the backend is not dependant from the filename
+The Filename of the file is changed. If the backend is not dependent from the filename
 nothing must happens. The rename must work on all versions of the file.
 
 Available C<PARAMS>:
@@ -199,5 +199,3 @@ L<SL::File>, L<SL::File::Object>
 Martin Helmling E<lt>martin.helmling@opendynamic.deE<gt>
 
 =cut
-
-

diff --git a/SL/File.pm b/SL/File.pm
index 231e0622f..31bebcfa4 100644
--- a/SL/File.pm
+++ b/SL/File.pm
@@ -356,7 +356,7 @@ SL::File - The intermediate Layer for handling files
 =head1 SYNOPSIS
 
   # In a controller or helper ( see SL::Controller::File or SL::Helper::File )
   # you can create, remove, delete etc. a file in a backend independant way
 
   my $file  = SL::File->save(
                      object_id     => $self->object_id,
@@ -384,7 +384,7 @@ SL::File - The intermediate Layer for handling files
 
 =head1 OVERVIEW
 
-The Filemanagemt can handle files in a storage independant way. Internal the File
+The Filemanagemt can handle files in a storage independent way. Internal the File
 use the configured storage backend for the type of file.
 These backends must be configured in L<SL::Controller::ClientConfig> or an extra database table.
 
@@ -704,4 +704,3 @@ The synchronization is done file_type by file_type.
 Martin Helmling E<lt>martin.helmling@opendynamic.deE<gt>
 
 =cut
-
@@ -356,7 +356,7 @@ SL::File - The intermediate Layer for handling files
 
   # In a controller or helper ( see SL::Controller::File or SL::Helper::File )
-  # you can create, remove, delete etc. a file in a backend independant way
+  # you can create, remove, delete etc. a file in a backend independent way
 
   my $file  = SL::File->save(